@@ -3,13 +3,9 @@ package PGObject::Simple;
 use 5.010;
 use strict;
 use warnings;
-use parent 'Exporter';
-
-use Carp::Clan qr/^PGObject\b/;
-use Log::Any qw($log);
-
+use Carp;
 use PGObject;
-
+use parent 'Exporter';
 
 =head1 NAME
 
@@ -17,11 +13,11 @@ PGObject::Simple - Minimalist stored procedure mapper based on LedgerSMB's DBObj
 
 =head1 VERSION
 
-Version 3.1.0
+Version 3.0.1
 
 =cut
 
-our $VERSION = '3.1.0';
+our $VERSION = 3.000001;
 
 =head1 SYNOPSIS
 
@@ -33,7 +29,7 @@ To call a stored procedure with enumerated arguments.
 
   my @results = $obj->call_procedure(
       funcname     => $funcname,
-      funcschema   => $funcschema,
+      funcschema   => $funcname,
       args         => [$arg1, $arg2, $arg3],
   );
 
@@ -41,7 +37,7 @@ You can add something like a running total as well:
 
   my @results = $obj->call_procedure(
       funcname      => $funcname,
-      funcschema    => $funcschema,
+      funcschema    => $funcname,
       args          => [$arg1, $arg2, $arg3],
       running_funcs => [{agg => 'sum(amount)', alias => 'total'}],
   );
@@ -51,7 +47,7 @@ typically done when mapping object properties in to stored procedure arguments.
 
   my @results = $obj->call_dbmethod(
       funcname      => $funcname,
-      funcschema    => $funcschema,
+      funcschema    => $funcname,
       running_funcs => [{agg => 'sum(amount)', alias => 'total'}],
   );
 
@@ -94,10 +90,10 @@ Below are the export tags listed including the leading ':' used to invoke them.
 =over
 
 =item :mapper
-            call_dbmethod, call_procedure, and set_dbh
+	    call_dbmethod, call_procedure, and set_dbh
 
 =item :full
-            All methods that can be exported at once.
+	    All methods that can be exported at once.
 
 =back
 
@@ -264,7 +260,7 @@ sub _arg_defaults {
         $args{funcschema} //= $self->{_func_schema};
         $args{funcprefix} //= eval {$self->_get_prefix() };
     } else { 
-        # see if we have package-level reader/factories
+	# see if we have package-level reader/factories
         $args{dbh} ||= "$self"->dbh; # if eval {"$self"->dbh};
         $args{funcschema} //= "$self"->funcschema if eval {"$self"->funcschema};
         $args{funcprefix} //= "$self"->funcprefix if eval {"$self"->funcprefix};
@@ -288,6 +284,7 @@ sub _self_to_arg { # refactored from map call, purely internal
     }
     $db_arg = $args->{args}->{$argname} if exists $args->{args}->{$argname};
     $db_arg = $db_arg->to_db if eval {$db_arg->can('to_db')};
+    $db_arg = { type => 'bytea', value => $db_arg} if $_->{type} eq 'bytea';
 
     return $db_arg;
 }
@@ -295,11 +292,8 @@ sub _self_to_arg { # refactored from map call, purely internal
 sub call_dbmethod {
     my ($self) = shift @_;
     my %args = @_;
-    croak $log->error( 'No function name provided' )
-        unless $args{funcname};
+    croak 'No function name provided' unless $args{funcname};
     %args = _arg_defaults($self, %args);
-    croak $log->error( 'No DB handle provided' )
-        unless $args{dbh};
     my $info = PGObject->function_info(%args);
 
     my $arglist = [];
@@ -329,8 +323,7 @@ simply returns the single first row returned.
 sub call_procedure {
     my ($self, %args) = @_;
     %args = _arg_defaults($self, %args);
-    croak $log->error( 'No DB handle provided' )
-        unless $args{dbh};
+    croak 'No DB handle provided' unless $args{dbh};
     my @rows = PGObject->call_procedure(%args);
     return shift @rows unless wantarray;
     return @rows;
@@ -340,9 +333,9 @@ sub call_procedure {
 
 Unlike PGObject, which is only loosely tied to the functionality in question
 and presumes that relevant information will be passed over a functional 
-interface, PGObject::Simple is a specific framework for object-oriented coding
-in Perl. It can therefore be used alone or with other modules to provide quite
-a bit of functionality.
+interface, PGObject is a specific framework for object-oriented coding in Perl.
+It can therefore be used alone or with other modules to provide quite a bit of
+functionality.
 
 A PGObject::Simple object is a blessed hashref with no gettors or setters.  This
 is thus ideal for cases where you are starting and just need some quick mappings
@@ -362,7 +355,7 @@ property name starts with 'in_' properly one must also prefix it).
 
 An example of a simple stored procedure might be:
 
-   CREATE OR REPLACE FUNCTION customer_get(in_id int)
+   CREATE OR REPLACE FUNCTION customer_get(in_id int) returns customer 
    RETURNS setof customer language sql as $$
 
    select * from customer where id = $1;
@@ -411,11 +404,19 @@ You can also look for information at:
 
 =item * RT: CPAN's request tracker (report bugs here)
 
-L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=PGObject-Simple>
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=PGObject-Simple>
 
-=item * MetaCPAN
+=item * AnnoCPAN: Annotated CPAN documentation
 
-L<https://metacpan.org/dist/PGObject-Simple>
+L<http://annocpan.org/dist/PGObject-Simple>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/PGObject-Simple>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/PGObject-Simple/>
 
 =back
 
@@ -425,8 +426,7 @@ L<https://metacpan.org/dist/PGObject-Simple>
 
 =head1 LICENSE AND COPYRIGHT
 
-  COPYRIGHT (C) 2013-2014 Chris Travers
-  COPYRIGHT (C) 2014-2021 The LedgerSMB Core Team
+Copyright 2013-2017 Chris Travers.
 
 Redistribution and use in source and compiled forms with or without 
 modification, are permitted provided that the following conditions are met:
